@@ -105,6 +105,9 @@ def preprocessing_training_common(df, config, industry_dictionary, state_diction
         logging.info( 'Saving iterative imputer to {}'.format( imputer_output_path ) )
         pickle.dump( imp, open( imputer_output_path, 'wb' ) )
 
+    # Impute growth columns
+    impute_growth_flag= config['impute_growth']
+    df=devutils.impute_growth(df=df,impute_growth_flag=impute_growth_flag)
     # Logs
     cols_to_transform = config['cols_to_transform']
     df = devutils.log_transformation( df, columns=cols_to_transform )
@@ -166,7 +169,7 @@ def preprocessing_training(df, industry_dictionary, state_dictionary,
     return df_leads_clean,imp
 
 
-def preprocessing_preleads(df,industry_dictionary,mx_bv_dictionary,mx_prob_dictionary,state_dictionary,imputer,sample):
+def preprocessing_preleads(df,industry_dictionary,state_dictionary,mx_bv_dictionary,mx_prob_dictionary,imputer,sample):
     """Pre processing function for batch preleads scoring
     
     Args:
@@ -182,12 +185,13 @@ def preprocessing_preleads(df,industry_dictionary,mx_bv_dictionary,mx_prob_dicti
     df_preleads_clean['Industry']= df_preleads_clean['Industry'].map(industry_dictionary)
     # map mxtypes
     df_preleads_clean= devutils.clean_mxtype_using_dictionary(df=df_preleads_clean, mx_bv_dict=mx_bv_dictionary,mx_prob_dict=mx_prob_dictionary)
-    # map states dictionary
-    df_preleads_clean['State']= df_preleads_clean['State'].map(state_dictionary)
+    
 
     #Fill NA with Uknown" in the following columns:
     cols_to_fill=['Type','Department','State']
     df_preleads_clean= devutils.fill_na_with_unknown(df=df_preleads_clean, columns= cols_to_fill)
+    # map states dictionary
+    df_preleads_clean['State']= df_preleads_clean['State'].map(state_dictionary)
 
     # Create company years column
     df_preleads_clean= devutils.create_company_years_column(df=df_preleads_clean)
@@ -208,6 +212,8 @@ def preprocessing_preleads(df,industry_dictionary,mx_bv_dictionary,mx_prob_dicti
     impute_columns = ['LeadFollowers','CompanyFollowers','QEmployeesOnLinkedIn','LeadConnections']
     df_preleads_clean=devutils.impute_nas(df=df_preleads_clean,columns_to_impute=impute_columns,imp=imputer)
 
+    #Impute growth columns
+
     # Log transformation
     cols_to_transform= ["QEmployeesOnLinkedIn","CompanyFollowers","LeadFollowers"]
     df_preleads_clean=devutils.log_transformation(df_preleads_clean,columns=cols_to_transform)
@@ -224,9 +230,9 @@ def preprocessing_preleads(df,industry_dictionary,mx_bv_dictionary,mx_prob_dicti
     logging.info( f"NA in final dataframe:" )
     logging.info( f"{nna}" )
 
-    df_preleads_clean = reduce_mem_usage_category(df_preleads_clean)
+    df_preleads_clean = utils.reduce_mem_usage_category(df_preleads_clean)
     df_preleads_clean = utils.one_hot_encoding(df=df_preleads_clean)
 
-    _, df_preleads_clean = sample.align(df_preleads_clean,join='left',axis=1,fill_value=np.nan)
+    _, df_preleads_clean = sample.align(df_preleads_clean,join='left',axis=1)
     
     return df_preleads_clean
