@@ -323,6 +323,14 @@ def filter_countries(df, countries,fixed_filter):
 
     return df
 
+def impute_growth(df,impute_growth_flag):
+    if impute_growth_flag==1:
+        df['Growth12M']=df['Growth12M'].fillna(df['Growth6M'])
+        df['Growth6M']=df['Growth6M'].fillna(df['Growth3M'])
+        df['Growth3M']=df['Growth3M'].fillna(df['Growth6M'])
+    return df
+    
+
 
 
 def convert_kwkey_specialties_and_technologies_to_int(df):
